@@ -1,5 +1,3 @@
-# coding: utf-8
-#
 # Copyright 2014 Thomas Amland <thomas.amland@gmail.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -46,13 +44,9 @@ if platform.is_linux():
 elif platform.is_darwin():
     from watchdog.observers.fsevents import FSEventsEmitter as Emitter
 elif platform.is_windows():
-    from watchdog.observers.read_directory_changes import (
-        WindowsApiEmitter as Emitter
-    )
+    from watchdog.observers.read_directory_changes import WindowsApiEmitter as Emitter
 elif platform.is_bsd():
-    from watchdog.observers.kqueue import (
-        KqueueEmitter as Emitter
-    )
+    from watchdog.observers.kqueue import KqueueEmitter as Emitter
 
 logging.basicConfig(level=logging.DEBUG)
 logger = logging.getLogger(__name__)
@@ -82,7 +76,9 @@ def start_watching(path=None, use_full_emitter=False, recursive=True):
     path = p() if path is None else path
     global emitter
     if platform.is_linux() and use_full_emitter:
-        emitter = InotifyFullEmitter(event_queue, ObservedWatch(path, recursive=recursive))
+        emitter = InotifyFullEmitter(
+            event_queue, ObservedWatch(path, recursive=recursive)
+        )
     else:
         emitter = Emitter(event_queue, ObservedWatch(path, recursive=recursive))
 
@@ -101,7 +97,7 @@ def rerun_filter(exc, *args):
 
 
 def expect_event(expected_event, timeout=2):
-    """ Utility function to wait up to `timeout` seconds for an `event_type` for `path` to show up in the queue.
+    """Utility function to wait up to `timeout` seconds for an `event_type` for `path` to show up in the queue.
 
     Provides some robustness for the otherwise flaky nature of asynchronous notifications.
     """
@@ -115,40 +111,42 @@ def expect_event(expected_event, timeout=2):
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_create():
     start_watching()
-    open(p('a'), 'a').close()
+    open(p("a"), "a").close()
 
-    expect_event(FileCreatedEvent(p('a')))
+    expect_event(FileCreatedEvent(p("a")))
 
     if not platform.is_windows():
         expect_event(DirModifiedEvent(p()))
 
     if platform.is_linux():
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('a')
+        assert event.src_path == p("a")
         assert isinstance(event, FileOpenedEvent)
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('a')
+        assert event.src_path == p("a")
         assert isinstance(event, FileClosedEvent)
 
 
-@pytest.mark.skipif(not platform.is_linux(), reason="FileCloseEvent only supported in GNU/Linux")
+@pytest.mark.skipif(
+    not platform.is_linux(), reason="FileCloseEvent only supported in GNU/Linux"
+)
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_close():
-    f_d = open(p('a'), 'a')
+    f_d = open(p("a"), "a")
     start_watching()
     f_d.close()
 
     # After file creation/open in append mode
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path == p('a')
+    assert event.src_path == p("a")
     assert isinstance(event, FileClosedEvent)
 
     event = event_queue.get(timeout=5)[0]
-    assert os.path.normpath(event.src_path) == os.path.normpath(p(''))
+    assert os.path.normpath(event.src_path) == os.path.normpath(p(""))
     assert isinstance(event, DirModifiedEvent)
 
     # After read-only, only IN_CLOSE_NOWRITE is emitted but not caught for now #747
-    open(p('a'), 'r').close()
+    open(p("a"), "r").close()
 
     assert event_queue.empty()
 
@@ -156,30 +154,30 @@ def test_close():
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 @pytest.mark.skipif(
     platform.is_darwin() or platform.is_windows(),
-    reason="Windows and macOS enforce proper encoding"
+    reason="Windows and macOS enforce proper encoding",
 )
 def test_create_wrong_encoding():
     start_watching()
-    open(p('a_\udce4'), 'a').close()
+    open(p("a_\udce4"), "a").close()
 
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path == p('a_\udce4')
+    assert event.src_path == p("a_\udce4")
     assert isinstance(event, FileCreatedEvent)
 
     if not platform.is_windows():
         event = event_queue.get(timeout=5)[0]
-        assert os.path.normpath(event.src_path) == os.path.normpath(p(''))
+        assert os.path.normpath(event.src_path) == os.path.normpath(p(""))
         assert isinstance(event, DirModifiedEvent)
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_delete():
-    mkfile(p('a'))
+    mkfile(p("a"))
 
     start_watching()
-    rm(p('a'))
+    rm(p("a"))
 
-    expect_event(FileDeletedEvent(p('a')))
+    expect_event(FileDeletedEvent(p("a")))
 
     if not platform.is_windows():
         expect_event(DirModifiedEvent(p()))
@@ -187,167 +185,171 @@ def test_delete():
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_modify():
-    mkfile(p('a'))
+    mkfile(p("a"))
     start_watching()
 
-    touch(p('a'))
+    touch(p("a"))
 
     if platform.is_linux():
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('a')
+        assert event.src_path == p("a")
         assert isinstance(event, FileOpenedEvent)
 
-    expect_event(FileModifiedEvent(p('a')))
+    expect_event(FileModifiedEvent(p("a")))
 
     if platform.is_linux():
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('a')
+        assert event.src_path == p("a")
         assert isinstance(event, FileClosedEvent)
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_chmod():
-    mkfile(p('a'))
+    mkfile(p("a"))
     start_watching()
 
     # Note: We use S_IREAD here because chmod on Windows only
     # allows setting the read-only flag.
-    os.chmod(p('a'), stat.S_IREAD)
+    os.chmod(p("a"), stat.S_IREAD)
 
-    expect_event(FileModifiedEvent(p('a')))
+    expect_event(FileModifiedEvent(p("a")))
 
     # Reset permissions to allow cleanup.
-    os.chmod(p('a'), stat.S_IWRITE)
+    os.chmod(p("a"), stat.S_IWRITE)
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_move():
-    mkdir(p('dir1'))
-    mkdir(p('dir2'))
-    mkfile(p('dir1', 'a'))
+    mkdir(p("dir1"))
+    mkdir(p("dir2"))
+    mkfile(p("dir1", "a"))
     start_watching()
 
-    mv(p('dir1', 'a'), p('dir2', 'b'))
+    mv(p("dir1", "a"), p("dir2", "b"))
 
     if not platform.is_windows():
-        expect_event(FileMovedEvent(p('dir1', 'a'), p('dir2', 'b')))
+        expect_event(FileMovedEvent(p("dir1", "a"), p("dir2", "b")))
     else:
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('dir1', 'a')
+        assert event.src_path == p("dir1", "a")
         assert isinstance(event, FileDeletedEvent)
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('dir2', 'b')
+        assert event.src_path == p("dir2", "b")
         assert isinstance(event, FileCreatedEvent)
 
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path in [p('dir1'), p('dir2')]
+    assert event.src_path in [p("dir1"), p("dir2")]
     assert isinstance(event, DirModifiedEvent)
 
     if not platform.is_windows():
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path in [p('dir1'), p('dir2')]
+        assert event.src_path in [p("dir1"), p("dir2")]
         assert isinstance(event, DirModifiedEvent)
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_case_change():
-    mkdir(p('dir1'))
-    mkdir(p('dir2'))
-    mkfile(p('dir1', 'file'))
+    mkdir(p("dir1"))
+    mkdir(p("dir2"))
+    mkfile(p("dir1", "file"))
     start_watching()
 
-    mv(p('dir1', 'file'), p('dir2', 'FILE'))
+    mv(p("dir1", "file"), p("dir2", "FILE"))
 
     if not platform.is_windows():
-        expect_event(FileMovedEvent(p('dir1', 'file'), p('dir2', 'FILE')))
+        expect_event(FileMovedEvent(p("dir1", "file"), p("dir2", "FILE")))
     else:
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('dir1', 'file')
+        assert event.src_path == p("dir1", "file")
         assert isinstance(event, FileDeletedEvent)
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('dir2', 'FILE')
+        assert event.src_path == p("dir2", "FILE")
         assert isinstance(event, FileCreatedEvent)
 
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path in [p('dir1'), p('dir2')]
+    assert event.src_path in [p("dir1"), p("dir2")]
     assert isinstance(event, DirModifiedEvent)
 
     if not platform.is_windows():
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path in [p('dir1'), p('dir2')]
+        assert event.src_path in [p("dir1"), p("dir2")]
         assert isinstance(event, DirModifiedEvent)
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_move_to():
-    mkdir(p('dir1'))
-    mkdir(p('dir2'))
-    mkfile(p('dir1', 'a'))
-    start_watching(p('dir2'))
+    mkdir(p("dir1"))
+    mkdir(p("dir2"))
+    mkfile(p("dir1", "a"))
+    start_watching(p("dir2"))
 
-    mv(p('dir1', 'a'), p('dir2', 'b'))
+    mv(p("dir1", "a"), p("dir2", "b"))
 
-    expect_event(FileCreatedEvent(p('dir2', 'b')))
+    expect_event(FileCreatedEvent(p("dir2", "b")))
 
     if not platform.is_windows():
-        expect_event(DirModifiedEvent(p('dir2')))
+        expect_event(DirModifiedEvent(p("dir2")))
 
 
-@pytest.mark.skipif(not platform.is_linux(), reason="InotifyFullEmitter only supported in Linux")
+@pytest.mark.skipif(
+    not platform.is_linux(), reason="InotifyFullEmitter only supported in Linux"
+)
 def test_move_to_full():
-    mkdir(p('dir1'))
-    mkdir(p('dir2'))
-    mkfile(p('dir1', 'a'))
-    start_watching(p('dir2'), use_full_emitter=True)
-    mv(p('dir1', 'a'), p('dir2', 'b'))
+    mkdir(p("dir1"))
+    mkdir(p("dir2"))
+    mkfile(p("dir1", "a"))
+    start_watching(p("dir2"), use_full_emitter=True)
+    mv(p("dir1", "a"), p("dir2", "b"))
 
     event = event_queue.get(timeout=5)[0]
     assert isinstance(event, FileMovedEvent)
-    assert event.dest_path == p('dir2', 'b')
+    assert event.dest_path == p("dir2", "b")
     assert event.src_path is None  # Should equal None since the path was not watched
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_move_from():
-    mkdir(p('dir1'))
-    mkdir(p('dir2'))
-    mkfile(p('dir1', 'a'))
-    start_watching(p('dir1'))
+    mkdir(p("dir1"))
+    mkdir(p("dir2"))
+    mkfile(p("dir1", "a"))
+    start_watching(p("dir1"))
 
-    mv(p('dir1', 'a'), p('dir2', 'b'))
+    mv(p("dir1", "a"), p("dir2", "b"))
 
-    expect_event(FileDeletedEvent(p('dir1', 'a')))
+    expect_event(FileDeletedEvent(p("dir1", "a")))
 
     if not platform.is_windows():
-        expect_event(DirModifiedEvent(p('dir1')))
+        expect_event(DirModifiedEvent(p("dir1")))
 
 
-@pytest.mark.skipif(not platform.is_linux(), reason="InotifyFullEmitter only supported in Linux")
+@pytest.mark.skipif(
+    not platform.is_linux(), reason="InotifyFullEmitter only supported in Linux"
+)
 def test_move_from_full():
-    mkdir(p('dir1'))
-    mkdir(p('dir2'))
-    mkfile(p('dir1', 'a'))
-    start_watching(p('dir1'), use_full_emitter=True)
-    mv(p('dir1', 'a'), p('dir2', 'b'))
+    mkdir(p("dir1"))
+    mkdir(p("dir2"))
+    mkfile(p("dir1", "a"))
+    start_watching(p("dir1"), use_full_emitter=True)
+    mv(p("dir1", "a"), p("dir2", "b"))
 
     event = event_queue.get(timeout=5)[0]
     assert isinstance(event, FileMovedEvent)
-    assert event.src_path == p('dir1', 'a')
+    assert event.src_path == p("dir1", "a")
     assert event.dest_path is None  # Should equal None since path not watched
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_separate_consecutive_moves():
-    mkdir(p('dir1'))
-    mkfile(p('dir1', 'a'))
-    mkfile(p('b'))
-    start_watching(p('dir1'))
-    mv(p('dir1', 'a'), p('c'))
-    mv(p('b'), p('dir1', 'd'))
+    mkdir(p("dir1"))
+    mkfile(p("dir1", "a"))
+    mkfile(p("b"))
+    start_watching(p("dir1"))
+    mv(p("dir1", "a"), p("c"))
+    mv(p("b"), p("dir1", "d"))
 
-    dir_modif = DirModifiedEvent(p('dir1'))
-    a_deleted = FileDeletedEvent(p('dir1', 'a'))
-    d_created = FileCreatedEvent(p('dir1', 'd'))
+    dir_modif = DirModifiedEvent(p("dir1"))
+    a_deleted = FileDeletedEvent(p("dir1", "a"))
+    d_created = FileCreatedEvent(p("dir1", "d"))
 
     expected_events = [a_deleted, dir_modif, d_created, dir_modif]
 
@@ -364,21 +366,25 @@ def test_separate_consecutive_moves():
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
-@pytest.mark.skipif(platform.is_bsd(), reason="BSD create another set of events for this test")
+@pytest.mark.skipif(
+    platform.is_bsd(), reason="BSD create another set of events for this test"
+)
 def test_delete_self():
-    mkdir(p('dir1'))
-    start_watching(p('dir1'))
-    rm(p('dir1'), True)
-    expect_event(DirDeletedEvent(p('dir1')))
+    mkdir(p("dir1"))
+    start_watching(p("dir1"))
+    rm(p("dir1"), True)
+    expect_event(DirDeletedEvent(p("dir1")))
     emitter.join(5)
     assert not emitter.is_alive()
 
 
-@pytest.mark.skipif(platform.is_windows() or platform.is_bsd(),
-                    reason="Windows|BSD create another set of events for this test")
+@pytest.mark.skipif(
+    platform.is_windows() or platform.is_bsd(),
+    reason="Windows|BSD create another set of events for this test",
+)
 def test_fast_subdirectory_creation_deletion():
-    root_dir = p('dir1')
-    sub_dir = p('dir1', 'subdir1')
+    root_dir = p("dir1")
+    sub_dir = p("dir1", "subdir1")
     times = 30
     mkdir(root_dir)
     start_watching(root_dir)
@@ -386,12 +392,12 @@ def test_fast_subdirectory_creation_deletion():
         mkdir(sub_dir)
         rm(sub_dir, True)
         time.sleep(0.1)  # required for macOS emitter to catch up with us
-    count = {DirCreatedEvent: 0,
-             DirModifiedEvent: 0,
-             DirDeletedEvent: 0}
-    etype_for_dir = {DirCreatedEvent: sub_dir,
-                     DirModifiedEvent: root_dir,
-                     DirDeletedEvent: sub_dir}
+    count = {DirCreatedEvent: 0, DirModifiedEvent: 0, DirDeletedEvent: 0}
+    etype_for_dir = {
+        DirCreatedEvent: sub_dir,
+        DirModifiedEvent: root_dir,
+        DirDeletedEvent: sub_dir,
+    }
     for _ in range(times * 4):
         event = event_queue.get(timeout=5)[0]
         logger.debug(event)
@@ -399,119 +405,127 @@ def test_fast_subdirectory_creation_deletion():
         count[etype] += 1
         assert event.src_path == etype_for_dir[etype]
         assert count[DirCreatedEvent] >= count[DirDeletedEvent]
-        assert count[DirCreatedEvent] + count[DirDeletedEvent] >= count[DirModifiedEvent]
-    assert count == {DirCreatedEvent: times,
-                     DirModifiedEvent: times * 2,
-                     DirDeletedEvent: times}
+        assert (
+            count[DirCreatedEvent] + count[DirDeletedEvent] >= count[DirModifiedEvent]
+        )
+    assert count == {
+        DirCreatedEvent: times,
+        DirModifiedEvent: times * 2,
+        DirDeletedEvent: times,
+    }
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_passing_unicode_should_give_unicode():
     start_watching(str(p()))
-    mkfile(p('a'))
+    mkfile(p("a"))
     event = event_queue.get(timeout=5)[0]
     assert isinstance(event.src_path, str)
 
 
-@pytest.mark.skipif(platform.is_windows(),
-                    reason="Windows ReadDirectoryChangesW supports only"
-                           " unicode for paths.")
+@pytest.mark.skipif(
+    platform.is_windows(),
+    reason="Windows ReadDirectoryChangesW supports only" " unicode for paths.",
+)
 def test_passing_bytes_should_give_bytes():
     start_watching(p().encode())
-    mkfile(p('a'))
+    mkfile(p("a"))
     event = event_queue.get(timeout=5)[0]
     assert isinstance(event.src_path, bytes)
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_recursive_on():
-    mkdir(p('dir1', 'dir2', 'dir3'), True)
+    mkdir(p("dir1", "dir2", "dir3"), True)
     start_watching()
-    touch(p('dir1', 'dir2', 'dir3', 'a'))
+    touch(p("dir1", "dir2", "dir3", "a"))
 
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path == p('dir1', 'dir2', 'dir3', 'a')
+    assert event.src_path == p("dir1", "dir2", "dir3", "a")
     assert isinstance(event, FileCreatedEvent)
 
     if not platform.is_windows():
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('dir1', 'dir2', 'dir3')
+        assert event.src_path == p("dir1", "dir2", "dir3")
         assert isinstance(event, DirModifiedEvent)
 
         if platform.is_linux():
             event = event_queue.get(timeout=5)[0]
-            assert event.src_path == p('dir1', 'dir2', 'dir3', 'a')
+            assert event.src_path == p("dir1", "dir2", "dir3", "a")
             assert isinstance(event, FileOpenedEvent)
 
         if not platform.is_bsd():
             event = event_queue.get(timeout=5)[0]
-            assert event.src_path == p('dir1', 'dir2', 'dir3', 'a')
+            assert event.src_path == p("dir1", "dir2", "dir3", "a")
             assert isinstance(event, FileModifiedEvent)
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
 def test_recursive_off():
-    mkdir(p('dir1'))
+    mkdir(p("dir1"))
     start_watching(recursive=False)
-    touch(p('dir1', 'a'))
+    touch(p("dir1", "a"))
 
     with pytest.raises(Empty):
         event_queue.get(timeout=5)
 
-    mkfile(p('b'))
-    expect_event(FileCreatedEvent(p('b')))
+    mkfile(p("b"))
+    expect_event(FileCreatedEvent(p("b")))
     if not platform.is_windows():
         expect_event(DirModifiedEvent(p()))
 
         if platform.is_linux():
-            expect_event(FileOpenedEvent(p('b')))
-            expect_event(FileClosedEvent(p('b')))
+            expect_event(FileOpenedEvent(p("b")))
+            expect_event(FileClosedEvent(p("b")))
 
     # currently limiting these additional events to macOS only, see https://github.com/gorakhargosh/watchdog/pull/779
     if platform.is_darwin():
-        mkdir(p('dir1', 'dir2'))
+        mkdir(p("dir1", "dir2"))
         with pytest.raises(Empty):
             event_queue.get(timeout=5)
-        mkfile(p('dir1', 'dir2', 'somefile'))
+        mkfile(p("dir1", "dir2", "somefile"))
         with pytest.raises(Empty):
             event_queue.get(timeout=5)
 
-        mkdir(p('dir3'))
-        expect_event(DirModifiedEvent(p()))  # the contents of the parent directory changed
+        mkdir(p("dir3"))
+        expect_event(
+            DirModifiedEvent(p())
+        )  # the contents of the parent directory changed
 
-        mv(p('dir1', 'dir2', 'somefile'), p('somefile'))
-        expect_event(FileMovedEvent(p('dir1', 'dir2', 'somefile'), p('somefile')))
+        mv(p("dir1", "dir2", "somefile"), p("somefile"))
+        expect_event(FileMovedEvent(p("dir1", "dir2", "somefile"), p("somefile")))
         expect_event(DirModifiedEvent(p()))
 
-        mv(p('dir1', 'dir2'), p('dir2'))
-        expect_event(DirMovedEvent(p('dir1', 'dir2'), p('dir2')))
+        mv(p("dir1", "dir2"), p("dir2"))
+        expect_event(DirMovedEvent(p("dir1", "dir2"), p("dir2")))
         expect_event(DirModifiedEvent(p()))
 
 
-@pytest.mark.skipif(platform.is_windows(),
-                    reason="Windows create another set of events for this test")
+@pytest.mark.skipif(
+    platform.is_windows(), reason="Windows create another set of events for this test"
+)
 def test_renaming_top_level_directory():
     start_watching()
 
-    mkdir(p('a'))
-    expect_event(DirCreatedEvent(p('a')))
+    mkdir(p("a"))
+    expect_event(DirCreatedEvent(p("a")))
     expect_event(DirModifiedEvent(p()))
 
-    mkdir(p('a', 'b'))
-    expect_event(DirCreatedEvent(p('a', 'b')))
-    expect_event(DirModifiedEvent(p('a')))
+    mkdir(p("a", "b"))
+    expect_event(DirCreatedEvent(p("a", "b")))
+    expect_event(DirModifiedEvent(p("a")))
 
-    mv(p('a'), p('a2'))
-    expect_event(DirMovedEvent(p('a'), p('a2')))
+    mv(p("a"), p("a2"))
+    expect_event(DirMovedEvent(p("a"), p("a2")))
     expect_event(DirModifiedEvent(p()))
     expect_event(DirModifiedEvent(p()))
 
-    expect_event(DirMovedEvent(p('a', 'b'), p('a2', 'b')))
+    expect_event(DirMovedEvent(p("a", "b"), p("a2", "b")))
 
     if platform.is_bsd():
         expect_event(DirModifiedEvent(p()))
 
-    open(p('a2', 'b', 'c'), 'a').close()
+    open(p("a2", "b", "c"), "a").close()
 
     # DirModifiedEvent may emitted, but sometimes after waiting time is out.
     events = []
@@ -520,49 +534,64 @@ def test_renaming_top_level_directory():
         if event_queue.empty():
             break
 
-    assert all([isinstance(e, (FileCreatedEvent, FileMovedEvent, FileOpenedEvent, DirModifiedEvent, FileClosedEvent))
-                for e in events])
+    assert all(
+        [
+            isinstance(
+                e,
+                (
+                    FileCreatedEvent,
+                    FileMovedEvent,
+                    FileOpenedEvent,
+                    DirModifiedEvent,
+                    FileClosedEvent,
+                ),
+            )
+            for e in events
+        ]
+    )
 
     for event in events:
         if isinstance(event, FileCreatedEvent):
-            assert event.src_path == p('a2', 'b', 'c')
+            assert event.src_path == p("a2", "b", "c")
         elif isinstance(event, FileMovedEvent):
-            assert event.dest_path == p('a2', 'b', 'c')
-            assert event.src_path == p('a', 'b', 'c')
+            assert event.dest_path == p("a2", "b", "c")
+            assert event.src_path == p("a", "b", "c")
         elif isinstance(event, DirModifiedEvent):
-            assert event.src_path == p('a2', 'b')
+            assert event.src_path == p("a2", "b")
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
-@pytest.mark.skipif(not platform.is_windows(),
-                    reason="Non-Windows create another set of events for this test")
+@pytest.mark.skipif(
+    not platform.is_windows(),
+    reason="Non-Windows create another set of events for this test",
+)
 def test_renaming_top_level_directory_on_windows():
     start_watching()
 
-    mkdir(p('a'))
+    mkdir(p("a"))
     event = event_queue.get(timeout=5)[0]
     assert isinstance(event, DirCreatedEvent)
-    assert event.src_path == p('a')
+    assert event.src_path == p("a")
 
-    mkdir(p('a', 'b'))
+    mkdir(p("a", "b"))
     event = event_queue.get(timeout=5)[0]
     assert isinstance(event, DirCreatedEvent)
-    assert event.src_path == p('a', 'b')
+    assert event.src_path == p("a", "b")
 
     event = event_queue.get(timeout=5)[0]
     assert isinstance(event, DirCreatedEvent)
-    assert event.src_path == p('a', 'b')
+    assert event.src_path == p("a", "b")
 
     event = event_queue.get(timeout=5)[0]
     assert isinstance(event, DirModifiedEvent)
-    assert event.src_path == p('a')
+    assert event.src_path == p("a")
 
-    mv(p('a'), p('a2'))
+    mv(p("a"), p("a2"))
     event = event_queue.get(timeout=5)[0]
     assert isinstance(event, DirMovedEvent)
-    assert event.src_path == p('a', 'b')
+    assert event.src_path == p("a", "b")
 
-    open(p('a2', 'b', 'c'), 'a').close()
+    open(p("a2", "b", "c"), "a").close()
 
     events = []
     while True:
@@ -570,35 +599,43 @@ def test_renaming_top_level_directory_on_windows():
         if event_queue.empty():
             break
 
-    assert all([isinstance(e, (FileCreatedEvent, FileMovedEvent, DirMovedEvent, DirModifiedEvent)) for e in events])
+    assert all(
+        [
+            isinstance(
+                e, (FileCreatedEvent, FileMovedEvent, DirMovedEvent, DirModifiedEvent)
+            )
+            for e in events
+        ]
+    )
 
     for event in events:
         if isinstance(event, FileCreatedEvent):
-            assert event.src_path == p('a2', 'b', 'c')
+            assert event.src_path == p("a2", "b", "c")
         elif isinstance(event, FileMovedEvent):
-            assert event.dest_path == p('a2', 'b', 'c')
-            assert event.src_path == p('a', 'b', 'c')
+            assert event.dest_path == p("a2", "b", "c")
+            assert event.src_path == p("a", "b", "c")
         elif isinstance(event, DirMovedEvent):
-            assert event.dest_path == p('a2')
-            assert event.src_path == p('a')
+            assert event.dest_path == p("a2")
+            assert event.src_path == p("a")
         elif isinstance(event, DirModifiedEvent):
-            assert event.src_path == p('a2', 'b')
+            assert event.src_path == p("a2", "b")
 
 
-@pytest.mark.skipif(platform.is_windows(),
-                    reason="Windows create another set of events for this test")
+@pytest.mark.skipif(
+    platform.is_windows(), reason="Windows create another set of events for this test"
+)
 def test_move_nested_subdirectories():
-    mkdir(p('dir1/dir2/dir3'), parents=True)
-    mkfile(p('dir1/dir2/dir3', 'a'))
+    mkdir(p("dir1/dir2/dir3"), parents=True)
+    mkfile(p("dir1/dir2/dir3", "a"))
     start_watching()
-    mv(p('dir1/dir2'), p('dir2'))
+    mv(p("dir1/dir2"), p("dir2"))
 
-    expect_event(DirMovedEvent(p('dir1', 'dir2'), p('dir2')))
-    expect_event(DirModifiedEvent(p('dir1')))
+    expect_event(DirMovedEvent(p("dir1", "dir2"), p("dir2")))
+    expect_event(DirModifiedEvent(p("dir1")))
     expect_event(DirModifiedEvent(p()))
 
-    expect_event(DirMovedEvent(p('dir1', 'dir2', 'dir3'), p('dir2', 'dir3')))
-    expect_event(FileMovedEvent(p('dir1', 'dir2', 'dir3', 'a'), p('dir2', 'dir3', 'a')))
+    expect_event(DirMovedEvent(p("dir1", "dir2", "dir3"), p("dir2", "dir3")))
+    expect_event(FileMovedEvent(p("dir1", "dir2", "dir3", "a"), p("dir2", "dir3", "a")))
 
     if platform.is_bsd():
         event = event_queue.get(timeout=5)[0]
@@ -606,47 +643,49 @@ def test_move_nested_subdirectories():
         assert isinstance(event, DirModifiedEvent)
 
         event = event_queue.get(timeout=5)[0]
-        assert p(event.src_path) == p('dir1')
+        assert p(event.src_path) == p("dir1")
         assert isinstance(event, DirModifiedEvent)
 
-    touch(p('dir2/dir3', 'a'))
+    touch(p("dir2/dir3", "a"))
 
     if platform.is_linux():
         event = event_queue.get(timeout=5)[0]
-        assert event.src_path == p('dir2/dir3', 'a')
+        assert event.src_path == p("dir2/dir3", "a")
         assert isinstance(event, FileOpenedEvent)
 
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path == p('dir2/dir3', 'a')
+    assert event.src_path == p("dir2/dir3", "a")
     assert isinstance(event, FileModifiedEvent)
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
-@pytest.mark.skipif(not platform.is_windows(),
-                    reason="Non-Windows create another set of events for this test")
+@pytest.mark.skipif(
+    not platform.is_windows(),
+    reason="Non-Windows create another set of events for this test",
+)
 def test_move_nested_subdirectories_on_windows():
-    mkdir(p('dir1/dir2/dir3'), parents=True)
-    mkfile(p('dir1/dir2/dir3', 'a'))
-    start_watching(p(''))
-    mv(p('dir1/dir2'), p('dir2'))
+    mkdir(p("dir1/dir2/dir3"), parents=True)
+    mkfile(p("dir1/dir2/dir3", "a"))
+    start_watching(p(""))
+    mv(p("dir1/dir2"), p("dir2"))
 
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path == p('dir1', 'dir2')
+    assert event.src_path == p("dir1", "dir2")
     assert isinstance(event, FileDeletedEvent)
 
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path == p('dir2')
+    assert event.src_path == p("dir2")
     assert isinstance(event, DirCreatedEvent)
 
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path == p('dir2', 'dir3')
+    assert event.src_path == p("dir2", "dir3")
     assert isinstance(event, DirCreatedEvent)
 
     event = event_queue.get(timeout=5)[0]
-    assert event.src_path == p('dir2', 'dir3', 'a')
+    assert event.src_path == p("dir2", "dir3", "a")
     assert isinstance(event, FileCreatedEvent)
 
-    touch(p('dir2/dir3', 'a'))
+    touch(p("dir2/dir3", "a"))
 
     events = []
     while True:
@@ -658,45 +697,47 @@ def test_move_nested_subdirectories_on_windows():
 
     for event in events:
         if isinstance(event, FileModifiedEvent):
-            assert event.src_path == p('dir2', 'dir3', 'a')
+            assert event.src_path == p("dir2", "dir3", "a")
         elif isinstance(event, DirModifiedEvent):
-            assert event.src_path in [p('dir2'), p('dir2', 'dir3')]
+            assert event.src_path in [p("dir2"), p("dir2", "dir3")]
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
-@pytest.mark.skipif(platform.is_bsd(), reason="BSD create another set of events for this test")
+@pytest.mark.skipif(
+    platform.is_bsd(), reason="BSD create another set of events for this test"
+)
 def test_file_lifecyle():
     start_watching()
 
-    mkfile(p('a'))
-    touch(p('a'))
-    mv(p('a'), p('b'))
-    rm(p('b'))
+    mkfile(p("a"))
+    touch(p("a"))
+    mv(p("a"), p("b"))
+    rm(p("b"))
 
-    expect_event(FileCreatedEvent(p('a')))
+    expect_event(FileCreatedEvent(p("a")))
 
     if not platform.is_windows():
         expect_event(DirModifiedEvent(p()))
 
     if platform.is_linux():
-        expect_event(FileOpenedEvent(p('a')))
-        expect_event(FileClosedEvent(p('a')))
+        expect_event(FileOpenedEvent(p("a")))
+        expect_event(FileClosedEvent(p("a")))
         expect_event(DirModifiedEvent(p()))
-        expect_event(FileOpenedEvent(p('a')))
+        expect_event(FileOpenedEvent(p("a")))
 
-    expect_event(FileModifiedEvent(p('a')))
+    expect_event(FileModifiedEvent(p("a")))
 
     if platform.is_linux():
-        expect_event(FileClosedEvent(p('a')))
+        expect_event(FileClosedEvent(p("a")))
         expect_event(DirModifiedEvent(p()))
 
-    expect_event(FileMovedEvent(p('a'), p('b')))
+    expect_event(FileMovedEvent(p("a"), p("b")))
 
     if not platform.is_windows():
         expect_event(DirModifiedEvent(p()))
         expect_event(DirModifiedEvent(p()))
 
-    expect_event(FileDeletedEvent(p('b')))
+    expect_event(FileDeletedEvent(p("b")))
 
     if not platform.is_windows():
         expect_event(DirModifiedEvent(p()))
