@@ -1,5 +1,3 @@
-# coding: utf-8
-#
 # Copyright 2011 Yesudeep Mangalapilly <yesudeep@gmail.com>
 # Copyright 2012 Google, Inc & contributors.
 #
@@ -17,7 +15,7 @@
 
 
 import os
-from . import Empty, Queue
+from queue import Empty, Queue
 from time import sleep
 
 import pytest
@@ -30,19 +28,12 @@ from watchdog.events import (
     FileModifiedEvent,
     DirMovedEvent,
     FileDeletedEvent,
-    DirDeletedEvent
+    DirDeletedEvent,
 )
 from watchdog.observers.api import ObservedWatch
 from watchdog.observers.polling import PollingEmitter as Emitter
 
-from .shell import (
-    mkdir,
-    mkdtemp,
-    touch,
-    rm,
-    mv,
-    msize
-)
+from .shell import mkdir, mkdtemp, touch, rm, mv, msize
 
 
 temp_dir = mkdtemp()
@@ -75,37 +66,37 @@ def test___init__(event_queue, emitter):
     SLEEP_TIME = 0.4
 
     sleep(SLEEP_TIME)
-    mkdir(p('project'))
+    mkdir(p("project"))
 
     sleep(SLEEP_TIME)
-    mkdir(p('project', 'blah'))
+    mkdir(p("project", "blah"))
 
     sleep(SLEEP_TIME)
-    touch(p('afile'))
+    touch(p("afile"))
 
     sleep(SLEEP_TIME)
-    touch(p('fromfile'))
+    touch(p("fromfile"))
 
     sleep(SLEEP_TIME)
-    mv(p('fromfile'), p('project', 'tofile'))
+    mv(p("fromfile"), p("project", "tofile"))
 
     sleep(SLEEP_TIME)
-    touch(p('afile'))
+    touch(p("afile"))
 
     sleep(SLEEP_TIME)
-    mv(p('project', 'blah'), p('project', 'boo'))
+    mv(p("project", "blah"), p("project", "boo"))
 
     sleep(SLEEP_TIME)
-    rm(p('project'), recursive=True)
+    rm(p("project"), recursive=True)
 
     sleep(SLEEP_TIME)
-    rm(p('afile'))
+    rm(p("afile"))
 
     sleep(SLEEP_TIME)
-    msize(p('bfile'))
+    msize(p("bfile"))
 
     sleep(SLEEP_TIME)
-    rm(p('bfile'))
+    rm(p("bfile"))
 
     sleep(SLEEP_TIME)
     emitter.stop()
@@ -117,40 +108,31 @@ def test___init__(event_queue, emitter):
     # A multiset! Python's collections.Counter class seems appropriate.
     expected = {
         DirModifiedEvent(p()),
-        DirCreatedEvent(p('project')),
-
-        DirModifiedEvent(p('project')),
-        DirCreatedEvent(p('project', 'blah')),
-
-        FileCreatedEvent(p('afile')),
+        DirCreatedEvent(p("project")),
+        DirModifiedEvent(p("project")),
+        DirCreatedEvent(p("project", "blah")),
+        FileCreatedEvent(p("afile")),
         DirModifiedEvent(p()),
-
-        FileCreatedEvent(p('fromfile')),
+        FileCreatedEvent(p("fromfile")),
         DirModifiedEvent(p()),
-
         DirModifiedEvent(p()),
-        FileModifiedEvent(p('afile')),
-
-        DirModifiedEvent(p('project')),
-
+        FileModifiedEvent(p("afile")),
+        DirModifiedEvent(p("project")),
         DirModifiedEvent(p()),
-        FileDeletedEvent(p('project', 'tofile')),
-        DirDeletedEvent(p('project', 'boo')),
-        DirDeletedEvent(p('project')),
-
+        FileDeletedEvent(p("project", "tofile")),
+        DirDeletedEvent(p("project", "boo")),
+        DirDeletedEvent(p("project")),
         DirModifiedEvent(p()),
-        FileDeletedEvent(p('afile')),
-
+        FileDeletedEvent(p("afile")),
         DirModifiedEvent(p()),
-        FileCreatedEvent(p('bfile')),
-        FileModifiedEvent(p('bfile')),
-
+        FileCreatedEvent(p("bfile")),
+        FileModifiedEvent(p("bfile")),
         DirModifiedEvent(p()),
-        FileDeletedEvent(p('bfile')),
+        FileDeletedEvent(p("bfile")),
     }
 
-    expected.add(FileMovedEvent(p('fromfile'), p('project', 'tofile')))
-    expected.add(DirMovedEvent(p('project', 'blah'), p('project', 'boo')))
+    expected.add(FileMovedEvent(p("fromfile"), p("project", "tofile")))
+    expected.add(DirMovedEvent(p("project", "blah"), p("project", "boo")))
 
     got = set()
 
@@ -167,7 +149,7 @@ def test___init__(event_queue, emitter):
 def test_delete_watched_dir(event_queue, emitter):
     SLEEP_TIME = 0.4
 
-    rm(p(''), recursive=True)
+    rm(p(""), recursive=True)
 
     sleep(SLEEP_TIME)
     emitter.stop()
@@ -178,7 +160,7 @@ def test_delete_watched_dir(event_queue, emitter):
     #   * non-unique
     # A multiset! Python's collections.Counter class seems appropriate.
     expected = {
-        DirDeletedEvent(os.path.dirname(p(''))),
+        DirDeletedEvent(os.path.dirname(p(""))),
     }
 
     got = set()
